@mixin font-feature-settings($settings...) {
  @include _bourbon-deprecate-for-prefixing("font-feature-settings");

  @if length($settings) == 0 { $settings: none; }
  @include prefixer(font-feature-settings, $settings, webkit moz ms spec);
}
