// Tooltips
// --------

.wy-tooltip
  position: absolute
  z-index: $z_index_tooltip
  display: block
  visibility: visible
  padding: 5px
  font-size: 11px
  opacity: 0
  +transition(opacity 2.0s ease-in)
  &.on
    opacity: .8
  &.top
    margin-top: -2px
  &.right
    margin-left: 2px
  &.bottom
    margin-top: 2px
  &.left
    margin-left: -2px
  &.top .wy-tooltip-arrow
    +arrow-top
  &.left .wy-tooltip-arrow
    +arrow-left
  &.bottom .wy-tooltip-arrow
    +arrow-bot
  &.right .wy-tooltip-arrow
    +arrow-right

.wy-tooltip-inner
  max-width: 200px
  padding: $base-font-size / 2
  color: $white
  text-align: center
  text-decoration: none
  background-color: $black
  border-radius: 4px

.wy-tooltip-arrow
  position: absolute
  width: 0
  height: 0



