// Video
//
// Styles from this page can be found in `wyrm_core/_video.sass`.
// It is basically a simple way to handle simple 16:9 responsive embeds.
//
// Markup:
// <div class="wy-video {$modifiers}"><iframe src="//www.youtube.com/embed/dJ0Neq2up9E" frameborder="0" allowfullscreen></iframe></div>
//
// .wy-video-sd         - 4:3 TV style
// .wy-video-cinema     - Anamorphic
//
// Styleguide 12.0

.wy-video
  position: relative
  padding-bottom: 56.25%
  height: 0
  iframe, object
    position: absolute
    top: 0
    left: 0
    width: 100%
    height: 100%

.wy-video.wy-video-sd
  padding-bottom: 75%
.wy-video.wy-video-cinema
  padding-bottom: 41.84%
