/* Tomorrow Night Eighties Theme
/* Original theme - https://github.com/chriskempson/tomorrow-theme
/* http://jmblog.github.com/color-themes-for-google-code-highlightjs

.hljs
  background: #2d2d2d
  color: #cccccc
  display: block
  padding: 0.5em
  white-space: pre
  font-family: Menlo, 'Bitstream Vera Sans Mono', 'DejaVu Sans Mono', Monaco, Consolas, monospace
  font-size: 12px
  line-height: 1.5
  padding: 10px
  overflow-x: auto
  width: 100%
  display: block
  border: none

/* Tomorrow Comment

.hljs-comment, .hljs-template_comment
  color: #999999

/* Tomorrow Red

.hljs-tag, .hljs-regexp, .ruby .hljs-constant, .hljs-title
  color: #f2777a

.xml
  .hljs-tag .hljs-title, .hljs-pi, .hljs-doctype
    color: #f2777a

.html .hljs-doctype
  color: #f2777a

.css
  .hljs-id, .hljs-class, .hljs-pseudo
    color: #f2777a

/* Tomorrow Orange

.hljs-number, .hljs-preprocessor, .hljs-pragma, .hljs-literal, .hljs-params, .hljs-attribute, .hljs-constant
  color: #f99157

/* Tomorrow Yellow

.ruby .hljs-class .hljs-title, .css .hljs-rules .hljs-attribute
  color: #ffcc66

/* Tomorrow Green

.hljs-string, .hljs-value, .hljs-inheritance, .hljs-header, .ruby .hljs-symbol, .xml .hljs-cdata
  color: #99cc99

/* Tomorrow Aqua

.css .hljs-hexcolor, .hljs-variable
  color: #66cccc

/* Tomorrow Blue

.hljs-function
  color: #6699cc

.python
  .hljs-decorator, .hljs-title
    color: #6699cc

.ruby
  .hljs-function .hljs-title, .hljs-title .hljs-keyword
    color: #6699cc

.perl .hljs-sub, .javascript .hljs-title, .coffeescript .hljs-title
  color: #6699cc

/* Tomorrow Purple

.hljs-keyword, .javascript .hljs-function
  color: #cc99cc

.hljs-template_tag
  color: white

.coffeescript .javascript, .javascript .xml, .tex .hljs-formula
  opacity: 0.5

.xml
  .javascript, .vbscript, .css, .hljs-cdata
    opacity: 0.5
