article, aside, details, figcaption, figure, footer, header, hgroup, nav, section
  display: block

audio, canvas, video
  display: inline-block
  *display: inline
  *zoom: 1

audio:not([controls])
  display: none

[hidden]
  display: none

*
  +box-sizing(border-box)

html
  font-size: 100%
  -webkit-text-size-adjust: 100%
  -ms-text-size-adjust: 100%

body
  margin: 0

a:hover, a:active
  outline: 0

abbr[title]
  border-bottom: 1px dotted

b, strong
  font-weight: bold

blockquote
  margin: 0

dfn
  font-style: italic


ins
  background: #ff9
  color: #000
  text-decoration: none

mark
  background: #ff0
  color: #000
  font-style: italic
  font-weight: bold

pre, code, kbd, samp
  font-family: monospace, serif
  _font-family: 'courier new', monospace
  font-size: 1em

pre
  white-space: pre

q
  quotes: none

q:before, q:after
  content: ""
  content: none

small
  font-size: 85%

sub, sup
  font-size: 75%
  line-height: 0
  position: relative
  vertical-align: baseline

sup
  top: -0.5em

sub
  bottom: -0.25em

ul, ol, dl
  margin: 0
  padding: 0
  list-style: none
  list-style-image: none

li
  list-style: none

dd
  margin: 0

img
  border: 0
  -ms-interpolation-mode: bicubic
  vertical-align: middle
  max-width: 100%

svg:not(:root)
  overflow: hidden

figure
  margin: 0

form
  margin: 0

fieldset
  border: 0
  margin: 0
  padding: 0

label
  cursor: pointer

legend
  border: 0
  *margin-left: -7px
  padding: 0
  white-space: normal

button, input, select, textarea
  font-size: 100%
  margin: 0
  vertical-align: baseline
  *vertical-align: middle

button, input
  line-height: normal

button, input[type="button"], input[type="reset"], input[type="submit"]
  cursor: pointer
  -webkit-appearance: button
  *overflow: visible

button[disabled], input[disabled]
  cursor: default

input[type="checkbox"], input[type="radio"]
  box-sizing: border-box
  padding: 0
  *width: 13px
  *height: 13px

input[type="search"]
  -webkit-appearance: textfield
  -moz-box-sizing: content-box
  -webkit-box-sizing: content-box
  box-sizing: content-box

input[type="search"]::-webkit-search-decoration, input[type="search"]::-webkit-search-cancel-button
  -webkit-appearance: none

button::-moz-focus-inner, input::-moz-focus-inner
  border: 0
  padding: 0

textarea
  overflow: auto
  vertical-align: top
  resize: vertical

table
  border-collapse: collapse
  border-spacing: 0

td
  vertical-align: top

.chromeframe
  margin: 0.2em 0
  background: #ccc
  color: black
  padding: 0.2em 0

.ir
  display: block
  border: 0
  text-indent: -999em
  overflow: hidden
  background-color: transparent
  background-repeat: no-repeat
  text-align: left
  direction: ltr
  *line-height: 0

.ir br
  display: none

.hidden
  display: none !important
  visibility: hidden

.visuallyhidden
  border: 0
  clip: rect(0 0 0 0)
  height: 1px
  margin: -1px
  overflow: hidden
  padding: 0
  position: absolute
  width: 1px

.visuallyhidden.focusable:active, .visuallyhidden.focusable:focus
  clip: auto
  height: auto
  margin: 0
  overflow: visible
  position: static
  width: auto

.invisible
  visibility: hidden

.relative
  position: relative

big, small
  font-size: 100%

@media print
  html, body, section
    background: none !important
  *
    box-shadow: none !important
    text-shadow: none !important
    filter: none !important
    -ms-filter: none !important
  a, a:visited
    text-decoration: underline
  .ir a:after, a[href^="javascript:"]:after, a[href^="#"]:after
    content: ""
  pre, blockquote
    page-break-inside: avoid
  thead
    display: table-header-group
  tr, img
    page-break-inside: avoid
  img
    max-width: 100% !important
  @page
    margin: 0.5cm

  p, h2, h3
    orphans: 3
    widows: 3
  h2, h3
    page-break-after: avoid
