// Default Icon styles that can be used with Font Awesome or similar font libs.

%icon
  font-family: inherit
  &:before
    font-family: $icon-font-family
    display: inline-block
    font-style: normal
    font-weight: normal
    line-height: 1
    text-decoration: inherit
    +font-smooth

.#{$icon-prefix}
  @extend %icon

a .#{$icon-prefix}
  display: inline-block
  text-decoration: inherit

.btn, .nav
  .#{$icon-prefix}
    display: inline
    &.#{$icon-prefix}-large
      line-height: .9em
    &.#{$icon-prefix}-spin
      display: inline-block

.btn.#{$icon-prefix}:before
  opacity: .5
  +transition(opacity .05s ease-in)
.btn.#{$icon-prefix}:hover:before
  opacity: 1

.btn-mini
  .#{$icon-prefix}:before
    font-size: 14px
    vertical-align: -15%
