// ------------------------------------------------------------
// WYRM TEST, KSS BUILD
// ------------------------------------------------------------
// This file exists to test wyrm compiles correctly with
// everything loaded. You should not use this in your project.
// It also includes some KSS specific styles at the bottom.
// ------------------------------------------------------------

// Variable defaults set by Wyrm
@import wyrm_core/wy_variables

// bourbon.io framework
@import bourbon

// Bourbon.io/neat framework, with some default media queries
@import wyrm_core/grid_settings
@import neat
// Add omega-type mixin, which is better for JS libraries like ember
// that add a bunch of extra elements in the dom.
@import wyrm_core/neat_extra

// Custom reset
@import wyrm_core/reset

// Wyrm mixins
@import wyrm_core/mixin

// Font awesome and overwrites.
@import font-awesome
@import wyrm_core/font_icon_defaults

// Wyrm core styles used in this theme
@import wyrm_core/alert
@import wyrm_core/button
@import wyrm_core/dropdown
@import wyrm_core/form
@import wyrm_core/generic
@import wyrm_core/table
@import wyrm_core/type
@import wyrm_core/spinner
@import wyrm_core/video

// Addons
@import wyrm_addons/forms/form_upload
@import wyrm_addons/forms/form_autocomplete
@import wyrm_addons/forms/form_tag
@import wyrm_addons/forms/form_gallery
@import wyrm_addons/pygments/pygments
@import wyrm_addons/pygments/pygments_light
@import wyrm_addons/elements/tooltip
@import wyrm_addons/elements/stars
@import wyrm_addons/elements/paginate
@import wyrm_addons/elements/modal
@import wyrm_addons/redactor/redactor
@import wyrm_addons/redactor/figures

// KSS Documentation styles.
@import wyrm_docs/kss
@import wyrm_docs/highlight
